@@ -18,11 +18,11 @@ class HWOException(Exception):
 
 
 class MCDException(Exception):
-    """ Exception """
+    """Exception"""
 
 
 class NHCException(Exception):
-    """ Exception """
+    """Exception"""
 
 
 class SAWException(Exception):
@@ -39,3 +39,19 @@ class UGCParseException(Exception):
 
 class CLIException(Exception):
     """Custom Exception for CLI Parsing Issues"""
+
+
+class InvalidPolygon(Exception):
+    """Parsing of polygon raised a known error condition."""
+
+
+class InvalidArguments(Exception):
+    """Provided method arguments were not valid (invalid units)."""
+
+
+class InvalidSHEFEncoding(Exception):
+    """Product is not encoded to SHEF standard specification."""
+
+
+class InvalidSHEFValue(Exception):
+    """SHEF element value fails to be processed to a float."""
