@@ -4,7 +4,7 @@ from collections import OrderedDict
 import re
 
 try:
-    from zoneinfo import ZoneInfo
+    from zoneinfo import ZoneInfo  # type: ignore
 except ImportError:
     from backports.zoneinfo import ZoneInfo
 
@@ -313,9 +313,22 @@ class TextProductSegment:
         for part in parts:
             pos = part.find("\n\n")
             if pos > 0:
-                bullets.append(" ".join(part[:pos].replace("\n", "").split()))
-            else:
-                bullets.append(" ".join(part.replace("\n", "").split()))
+                part = part[:pos]
+            # look for subheadings :/
+            piece = ""
+            for line in part.split("\n"):
+                if line.strip().startswith("- "):
+                    if piece != "":
+                        bullets.append(piece)
+                    piece = line.split("- ", 1)[1]
+                    continue
+                if piece != "":
+                    piece += f" {line} "
+            if piece != "":
+                bullets.append(piece)
+            bullets.append(" ".join(part.replace("\n", "").split()))
+        # Cleanup
+        bullets = [" ".join(b.split()) for b in bullets]
         return bullets
 
     def process_tags(self):
@@ -470,7 +483,7 @@ class TextProductSegment:
         # check 2, is the exterior ring of the polygon clockwise?
         if poly.exterior.is_ccw:
             # No longer a warning as it was too much noise
-            LOG.info(
+            LOG.warning(
                 "LAT...LON polygon exterior is CCW, reversing\n%s",
                 poly.exterior.xy,
             )
@@ -526,7 +539,7 @@ class TextProductSegment:
         else:
             pairs = []
             for lat, lon in zip(lats, lons):
-                pairs.append("%s %s" % (lon, lat))
+                pairs.append(f"{lon} {lat}")
             self.tml_giswkt = "SRID=4326;LINESTRING(%s)" % (",".join(pairs),)
         self.tml_sknt = int(gdict["sknt"])
         self.tml_dir = int(gdict["dir"])
@@ -687,14 +700,14 @@ class TextProduct:
         aaa = self.afos[:3]
         hdl = self.get_main_headline()
         data = {
-            "headline": " ...%s..." % (hdl,) if hdl != "" else "",
+            "headline": f" ...{hdl}..." if hdl != "" else "",
             "source": self.source[1:],
             "aaa": aaa,
             "name": reference.prodDefinitions.get(
                 aaa, reference.prodDefinitions.get(self.afos, self.afos)
             ),
             "stamp": self.get_nicedate(),
-            "url": "%s?pid=%s" % (uri, self.get_product_id()),
+            "url": f"{uri}?pid={self.get_product_id()}",
         }
         res = []
         plain = (templates[0] + "%(url)s") % data
