@@ -1,6 +1,6 @@
 """Off-loaded private stuff from `vtec.py`."""
 # pylint: disable=too-many-arguments
-from datetime import timedelta
+from datetime import timedelta, timezone
 import itertools
 
 import pandas as pd
@@ -14,11 +14,13 @@ DEFAULT_EXPIRE_DELTA = timedelta(hours=(21 * 24))
 
 def which_year(txn, prod, segment, vtec):
     """Figure out which table we should work against"""
+    # The case of a NEW event always goes into the current UTC year of prod
     if vtec.action in ["NEW"]:
         # Lets piggyback a check to see if this ETN has been reused?
         # Can this realiably be done?
         txn.execute(
-            f"SELECT max(updated) from warnings_{prod.db_year} WHERE wfo = %s "
+            f"SELECT max(updated) from warnings_{prod.valid.year} "
+            "WHERE wfo = %s "
             "and eventid = %s and significance = %s and phenomena = %s",
             (vtec.office, vtec.etn, vtec.significance, vtec.phenomena),
         )
@@ -28,11 +30,11 @@ def which_year(txn, prod, segment, vtec):
                 prod.warnings.append(
                     "Possible Duplicated ETN\n"
                     f"  max(updated) is {row['max']}, "
-                    f"prod.valid is {prod.valid}\n year is {prod.db_year}\n"
+                    f"prod.valid is {prod.valid}\n"
                     f"  VTEC: {str(vtec)}\n  "
                     f"product_id: {prod.get_product_id()}"
                 )
-        return prod.db_year
+        return prod.valid.year
     # Lets query the database to look for any matching entries within
     # the past 3, 10, 31 days, to find with the product_issue was,
     # which guides the table that the data is stored within
@@ -40,7 +42,8 @@ def which_year(txn, prod, segment, vtec):
         txn.execute(
             "SELECT tableoid::regclass as tablename, hvtec_nwsli, "
             "min(product_issue at time zone 'UTC'), "
-            "max(product_issue at time zone 'UTC') from warnings "
+            "max(product_issue at time zone 'UTC'), "
+            "min(issue at time zone 'UTC') as min_issue from warnings "
             "WHERE wfo = %s and eventid = %s and significance = %s and "
             "phenomena = %s and ((updated > %s and updated <= %s) "
             "or expire > %s) and status not in ('UPG', 'CAN') "
@@ -59,6 +62,13 @@ def which_year(txn, prod, segment, vtec):
         if not rows:
             continue
         if len(rows) > 1:
+            # We could have an ambiguious situation around the new year, so
+            # we attempt to use the issue to resolve this.
+            if vtec.begints is not None:
+                for row in rows:
+                    mi = row["min_issue"].replace(tzinfo=timezone.utc)
+                    if mi == vtec.begints:
+                        return int(row["tablename"].replace("warnings_", ""))
             # We likely have a flood warning and can use the HVTEC NWSLI
             # to resolve ambiguity
             hvtec_nwsli = segment.get_hvtec_nwsli()
@@ -68,17 +78,15 @@ def which_year(txn, prod, segment, vtec):
                         return int(row["tablename"].replace("warnings_", ""))
 
             prod.warnings.append(
-                (
-                    "VTEC %s product: %s returned %s rows when "
-                    "searching for current table"
-                )
-                % (str(vtec), prod.get_product_id(), txn.rowcount)
+                f"VTEC {vtec} product: {prod.get_product_id()} "
+                f"returned {txn.rowcount} rows when searching "
+                "for current table"
             )
         row = rows[0]
         if row["min"] is not None:
             year = row["min"].year
             if row["max"].year != year:
-                LOG.info(
+                LOG.warning(
                     "VTEC Product appears to cross 1 Jan UTC "
                     "minyear: %s maxyear: %s VTEC: %s productid: %s",
                     year,
@@ -90,14 +98,14 @@ def which_year(txn, prod, segment, vtec):
 
     # Give up
     if not prod.is_correction():
-        table = f"warnings_{prod.db_year}"
+        table = f"warnings_{prod.valid.year}"
         prod.warnings.append(
             "Failed to find year of product issuance:\n"
             f"  VTEC:{str(vtec)}\n  PRODUCT: {prod.get_product_id()}\n"
-            f"  defaulting to use year: {prod.db_year}\n"
+            f"  defaulting to use year: {prod.valid.year}\n"
             f"  {list_rows(txn, table, vtec)}"
         )
-    return prod.db_year
+    return prod.valid.year
 
 
 def _associate_vtec_year(prod, txn):
@@ -176,10 +184,10 @@ def check_dup_ps(segment):
         )
         val.append([thisvtec.begints, endts])
 
-    for key in combos:
-        if len(combos[key]) == 1:
+    for _key, combo in combos.items():
+        if len(combo) == 1:
             continue
-        for one, two in itertools.permutations(combos[key], 2):
+        for one, two in itertools.permutations(combo, 2):
             # We check for overlap
             if one[0] >= two[0] and one[0] < two[1]:
                 return True
@@ -206,9 +214,8 @@ def do_sql_hvtec(txn, segment):
             forecast_text = bullet
         if bsu.find("AT ") == 0 and stage_text == "":
             stage_text = bullet
-        if bsu.startswith("IMPACT..."):
-            impact_text = bullet.strip()[9:]
-
+        if bsu.startswith("IMPACT"):
+            impact_text = bullet.split("...", 1)[1].strip()
     txn.execute(
         "INSERT into riverpro(nwsli, stage_text, flood_text, forecast_text, "
         "impact_text, severity) VALUES (%s,%s,%s,%s,%s,%s)",
@@ -265,7 +272,7 @@ def _debug_warning(prod, txn, warning_table, vtec, segment, ets):
 
     def myfmt(val):
         """Be more careful"""
-        default = "%-16s" % ("((NULL))",)
+        default = f"{'((NULL))':>16}"
         return default if val is None else val.strftime("%Y-%m-%d %H:%M")
 
     for row in txn.fetchall():
@@ -291,7 +298,9 @@ def _resent_match(prod, txn, warning_table, vtec):
     )
     maxtime = txn.fetchone()["maxtime"]
     if maxtime is not None and maxtime == prod.valid:
-        LOG.info("RESENT Match, skipping SQL for %s!", prod.get_product_id())
+        LOG.warning(
+            "RESENT Match, skipping SQL for %s!", prod.get_product_id()
+        )
         return True
     return False
 
@@ -437,7 +446,7 @@ def _do_sql_vtec_can(prod, txn, warning_table, segment, vtec):
     # An EXT action could change the issuance time, gasp
     issuesql = ""
     if vtec.action == "EXT" and vtec.begints is not None:
-        issuesql = " issue = '%s', " % (vtec.begints,)
+        issuesql = f" issue = '{vtec.begints}', "
     txn.execute(
         f"UPDATE {warning_table} SET {issuesql} expire = %s, "
         "status = %s, updated = %s, "
