@@ -45,6 +45,10 @@ REGIMES = [
         "DEPARTURE    LAST"
     ),
     "WEATHER ITEM   OBSERVED RECORD YEAR     LAST",
+    (
+        "WEATHER ITEM  OBSERVED    TIME      RECORD    YEAR    NORMAL   "
+        "DEPARTURE   LAST"
+    ),
 ]
 # label, value, time, record, year, normal, departure, last
 COLS = [
@@ -68,6 +72,7 @@ COLS = [
     [16, 23, 30, 37, None, 44, 51, 60],
     [16, 23, 34, 40, 50, 58, 67, 80],
     [16, 23, None, 30, 35, None, None, 44],
+    [16, 23, 33, 40, 51, 59, 69, 79],
 ]
 # Allow manual provision of IDS
 HARDCODED = {}
@@ -87,37 +92,38 @@ def update_iemaccess(txn, entry):
     if data.get("temperature_maximum") is not None:
         climax = int(data["temperature_maximum"])
         if climax != current["max_tmpf"]:
-            logmsg.append("MaxT O:%s N:%s" % (current["max_tmpf"], climax))
+            logmsg.append(f"MaxT O:{current['max_tmpf']} N:{climax}")
             current["max_tmpf"] = climax
 
     if data.get("temperature_minimum") is not None:
         climin = int(data["temperature_minimum"])
         if climin != current["min_tmpf"]:
-            logmsg.append("MinT O:%s N:%s" % (current["min_tmpf"], climin))
+            logmsg.append(f"MinT O:{current['min_tmpf']} N:{climin}")
             current["min_tmpf"] = climin
 
     if data.get("precip_month") is not None:
         val = data["precip_month"]
         if val != current["pmonth"]:
-            logmsg.append("PMonth O:%s N:%s" % (current["pmonth"], val))
+            logmsg.append(f"PMonth O:{current['pmonth']} N:{val}")
             current["pmonth"] = val
 
     if data.get("precip_today") is not None:
         val = data["precip_today"]
         if val != current["pday"]:
-            logmsg.append("PDay O:%s N:%s" % (current["pday"], val))
+            logmsg.append(f"PDay O:{current['pday']} N:{val}")
             current["pday"] = val
 
-    if data.get("snow_today") is not None:
-        val = data["snow_today"]
-        if current["snow"] is None or val != current["snow"]:
-            logmsg.append("Snow O:%s N:%s" % (current["snow"], val))
-            current["snow"] = val
+    for dkey, ikey in {"snow_today": "snow", "snowdepth": "snowd"}.items():
+        if data.get(dkey) is not None:
+            val = data[dkey]
+            if current[ikey] is None or val != current[ikey]:
+                logmsg.append(f"{ikey} O:{current[ikey]} N:{val}")
+                current[ikey] = val
 
     if not logmsg:
         return True
     res = ob.save(txn, skip_current=True)
-    LOG.info(
+    LOG.warning(
         "%s (%s) %s ob.save: %s",
         entry["access_station"],
         entry["cli_valid"].strftime("%y%m%d"),
@@ -129,11 +135,11 @@ def update_iemaccess(txn, entry):
 
 def trace_r(val):
     """Convert our value back into meaningful string"""
-    if val is None:
+    if val is None or val == "M":
         return "Missing"
     if val == TRACE_VALUE:
         return "Trace"
-    return val
+    return f'{val}"'
 
 
 def get_number_year(text):
@@ -163,7 +169,7 @@ def get_number(text):
             else:
                 retval = int(number[0])
         else:
-            LOG.info("get_number() failed for |%s|", text)
+            LOG.warning("get_number() failed for |%s|", text)
             retval = None
     return retval
 
@@ -180,7 +186,7 @@ def convert_key(text):
         return "month"
     if text.startswith("SINCE "):
         return text.replace("SINCE ", "").replace(" ", "").lower()
-    LOG.info("convert_key() failed for |%s|", text)
+    LOG.warning("convert_key() failed for |%s|", text)
     return "fail"
 
 
@@ -211,7 +217,8 @@ def parse_snowfall(regime, lines, data):
             continue
         tokens = make_tokens(regime, line)
         key = tokens[0].strip()
-        if key == "SNOW DEPTH":
+        if key.startswith("SNOW DEPTH"):
+            data["snowdepth"] = get_number(tokens[1])
             continue
         key = convert_key(key)
         data[f"snow_{key}"] = get_number(tokens[1])
@@ -410,10 +417,11 @@ def sql_data(prod, cursor, data):
         snow_jul1_normal, snow_dec1_normal, snow_month_normal, precip_jun1,
         precip_jun1_normal, average_sky_cover, resultant_wind_speed,
         resultant_wind_direction, highest_wind_speed, highest_wind_direction,
-        highest_gust_speed, highest_gust_direction, average_wind_speed)
+        highest_gust_speed, highest_gust_direction, average_wind_speed,
+        snowdepth)
         VALUES (%s, %s, %s, %s, %s, %s, %s, %s, %s, %s, %s, %s, %s, %s, %s, %s,
         %s, %s, %s, %s, %s, %s, %s, %s, %s, %s, %s, %s, %s, %s, %s, %s, %s, %s,
-        %s, %s, %s, %s, %s, %s, %s, %s, %s, %s, %s, %s)
+        %s, %s, %s, %s, %s, %s, %s, %s, %s, %s, %s, %s, %s)
         """,
         (
             data["db_station"],
@@ -462,6 +470,7 @@ def sql_data(prod, cursor, data):
             dd.get("highest_gust_speed"),
             dd.get("highest_gust_direction"),
             dd.get("average_wind_speed"),
+            dd.get("snowdepth"),
         ),
     )
 
@@ -482,7 +491,7 @@ class CLIProduct(TextProduct):
         # Sometimes, we get products that are not really in CLI format but
         # are RER (record event reports) with a CLI AWIPS ID
         if self.wmo[:2] != "CD":
-            LOG.info(
+            LOG.warning(
                 "Product %s skipped due to wrong header", self.get_product_id()
             )
             return
@@ -551,34 +560,31 @@ class CLIProduct(TextProduct):
             "product_id": self.get_product_id(),
         }
         for data in self.data:
-            msg = "High: %s Low: %s Precip: %s Snow: %s" % (
-                data["data"].get("temperature_maximum", "M"),
-                data["data"].get("temperature_minimum", "M"),
-                trace_r(data["data"].get("precip_today", "M")),
-                trace_r(data["data"].get("snow_today", "M")),
+            msg = (
+                f"High: {data['data'].get('temperature_maximum', 'M')} "
+                f"Low: {data['data'].get('temperature_minimum', 'M')} "
+                f"Precip: {trace_r(data['data'].get('precip_today','M'))} "
+                f"Snow: {trace_r(data['data'].get('snow_today', 'M'))}"
             )
-            mess = ("%s %s Climate Report: %s %s") % (
-                data["cli_station"],
-                data["cli_valid"].strftime("%b %-d"),
-                msg,
-                url,
+            sd = data["data"].get("snowdepth")
+            if sd is not None:
+                msg += f" Snow Depth: {trace_r(sd)}"
+            mess = (
+                f"{data['cli_station']} {data['cli_valid']:%b %-d} "
+                f"Climate Report: {msg} {url}"
             )
-            htmlmess = ('%s <a href="%s">%s Climate Report</a>: %s') % (
-                data["cli_station"],
-                url,
-                data["cli_valid"].strftime("%b %-d"),
-                msg,
+            htmlmess = (
+                f'{data["cli_station"]} <a href="{url}">'
+                f'{data["cli_valid"]:%b %-d} Climate Report</a>: {msg}'
             )
             xtra["twitter_media"] = (
                 "https://mesonet.agron.iastate.edu/plotting/auto/plot/218/"
                 f"network:NWSCLI::station:{data['db_station']}::"
                 f"date:{data['cli_valid'].strftime('%Y-%m-%d')}.png"
             )
-            xtra["twitter"] = ("%s %s Climate: %s %s") % (
-                data["cli_station"],
-                data["cli_valid"].strftime("%b %-d"),
-                msg,
-                url,
+            xtra["twitter"] = (
+                f"{data['cli_station']} {data['cli_valid']:%b %-d} "
+                f"Climate: {msg} {url}"
             )
             res.append(
                 [
@@ -629,12 +635,8 @@ class CLIProduct(TextProduct):
             sql_data(self, cursor, entry)
             if not update_iemaccess(cursor, entry):
                 self.warnings.append(
-                    "IEMAccess Update failed %s %s %s"
-                    % (
-                        entry["access_network"],
-                        entry["access_station"],
-                        entry["cli_valid"],
-                    )
+                    f"IEMAccess Update failed {entry['access_network']} "
+                    f"{entry['access_station']} {entry['cli_valid']}"
                 )
 
 
