@@ -3,7 +3,7 @@ import re
 from datetime import timezone, timedelta
 
 try:
-    from zoneinfo import ZoneInfo
+    from zoneinfo import ZoneInfo  # type: ignore
 except ImportError:
     from backports.zoneinfo import ZoneInfo
 
@@ -115,10 +115,10 @@ def to_metar(textprod, text):
     if mtr is not None:
         # Attempt to figure out more things
         if mtr.station_id is None:
-            LOG.info("Aborting due to station_id being None |%s|", text)
+            LOG.warning("Aborting due to station_id being None |%s|", text)
             return None
         if mtr.time is None:
-            LOG.info("Aborting due to time being None |%s|", text)
+            LOG.warning("Aborting due to time being None |%s|", text)
             return None
         # don't allow data more than an hour into the future
         ceiling = (textprod.utcnow + timedelta(hours=1)).replace(tzinfo=None)
@@ -130,7 +130,7 @@ def to_metar(textprod, text):
                     year=prevmonth.year, month=prevmonth.month
                 )
             else:
-                LOG.info(
+                LOG.warning(
                     "Aborting due to time in the future "
                     "ceiling: %s mtr.time: %s",
                     ceiling,
@@ -203,16 +203,17 @@ class METARReport(Metar):
                 sknt = v1
                 drct = d1
                 time = t1
-        key = "%s;%s;%s" % (self.station_id, sknt, time)
-        if key not in WIND_ALERTS:
-            WIND_ALERTS[key] = 1
-            speed = datatypes.speed(sknt, "KT")
-            return ("gust of %.0f knots (%.1f mph) from %s @ %s") % (
-                speed.value("KT"),
-                speed.value("MPH"),
-                drct2text(drct),
-                time.strftime("%H%MZ"),
-            )
+        key = f"{self.station_id};{sknt};{time}"
+        if key in WIND_ALERTS:
+            return None
+        WIND_ALERTS[key] = 1
+        speed = datatypes.speed(sknt, "KT")
+        return ("gust of %.0f knots (%.1f mph) from %s @ %s") % (
+            speed.value("KT"),
+            speed.value("MPH"),
+            drct2text(drct),
+            time.strftime("%H%MZ"),
+        )
 
     def over_wind_threshold(self):
         """Is this METAR over the wind threshold for alerting"""
@@ -299,7 +300,7 @@ class METARReport(Metar):
             alti = self.press.value("MB")
             mslp = self.press_sea_level.value("MB")
             if abs(alti - mslp) > 25:
-                LOG.info(
+                LOG.warning(
                     "PRESSURE ERROR %s %s ALTI: %s MSLP: %s",
                     iem.data["station"],
                     iem.data["valid"],
@@ -383,7 +384,7 @@ class METARCollective(TextProduct):
                 row = self.nwsli_provider.get(mtr.iemid, {})
                 wfo = row.get("wfo")
                 if wfo is None or wfo == "":
-                    LOG.info(
+                    LOG.warning(
                         "Unknown WFO for id: %s, skipping alert", mtr.iemid
                     )
                     continue
