@@ -180,7 +180,7 @@ class Pirep(product.TextProduct):
             # First token is always priority
             if i == 0:
                 if len(token) > 10:
-                    LOG.info("Aborting as not-PIREP? |%s|", report)
+                    LOG.warning("Aborting as not-PIREP? |%s|", report)
                     return None
                 if token.find(" UUA") > 0:
                     _pr.priority = Priority.UUA
@@ -274,7 +274,7 @@ class Pirep(product.TextProduct):
             if token.startswith("TM "):
                 numbers = re.findall("[0-9]{4}", token)
                 if len(numbers) != 1:
-                    self.warnings.append("TM parse failed %s" % (report,))
+                    self.warnings.append(f"TM parse failed {report}")
                     return None
                 hour = int(numbers[0][:2])
                 minute = int(numbers[0][2:])
