@@ -31,7 +31,7 @@ TODO List
 try:
     from zoneinfo import ZoneInfo  # type: ignore
 except ImportError:
-    from backports.zoneinfo import ZoneInfo
+    from backports.zoneinfo import ZoneInfo  # type: ignore
 from datetime import date, timezone, datetime, timedelta
 from io import StringIO
 import traceback
@@ -127,6 +127,28 @@ def parse_dc(text, basevalid):
     return datetime24(basevalid, replacements)
 
 
+def parse_dy(text, basevalid):
+    """Convert the DY element into a timestamp."""
+    text = text.strip()
+    replacements = {}
+    # always YY
+    yy = int(text[:2])
+    replacements["year"] = (1900 if yy > 80 else 2000) + yy
+    if len(text) >= 4:
+        replacements["month"] = int(text[2:4])
+    if len(text) >= 6:
+        replacements["day"] = int(text[4:6])
+    if len(text) >= 8:
+        replacements["hour"] = int(text[6:8])
+        if len(text) >= 10:
+            replacements["minute"] = int(text[8:10])
+    else:
+        # default to 12z
+        replacements["hour"] = 12
+
+    return datetime24(basevalid, replacements)
+
+
 def datetime24(dt, replacements):
     """Handle the junkiness that is a `24` hour."""
     # dt could be a date
@@ -170,7 +192,7 @@ def parse_station_valid(text, utcnow):
       utcnow (datetime): The default time.
 
     Returns:
-      str, datetime, list
+      str, datetime, datetime, list
     """
     tokens = text.split()
     station = tokens[1]
@@ -180,7 +202,7 @@ def parse_station_valid(text, utcnow):
     if all(x.isalpha() for x in timestamp):
         raise InvalidSHEFEncoding(f"3.2 No timestamp in '{text}'")
     # Ensure that the timestamp is all numbers
-    valid = make_date(timestamp, utcnow)
+    basevalid = make_date(timestamp, utcnow)
     # 4.1.4 Timezone is optional, default to Z
     if len(tokens) >= 4 and tokens[3] in TIMEZONES:
         tzinfo = ZoneInfo(TIMEZONES[tokens[3]])
@@ -188,22 +210,23 @@ def parse_station_valid(text, utcnow):
     else:
         tzinfo = timezone.utc
         startidx = 3
-    valid = datetime24(valid, {"tzinfo": tzinfo})
+    basevalid = datetime24(basevalid, {"tzinfo": tzinfo})
     extra = []
     # Look to see what we have here, saving off extra things we can not parse
     if len(tokens) == startidx:
         replacements = {"hour": 12 if tzinfo == timezone.utc else 0}
-        valid = datetime24(valid, replacements)
-        return station, valid, extra
+        basevalid = datetime24(basevalid, replacements)
+        return station, basevalid, basevalid, extra
     workdone = False
+    valid = basevalid
     for token in tokens[startidx:]:
         pe = token[:2]
         # Default replacement from above
         if pe.startswith("DH"):
-            valid = parse_dh(token[2:], valid)
+            valid = parse_dh(token[2:], basevalid)
             workdone = True
         elif pe.startswith("DM"):
-            valid = parse_dm(token[2:], valid)
+            valid = parse_dm(token[2:], basevalid)
             workdone = True
         else:
             extra.append(token)
@@ -212,7 +235,8 @@ def parse_station_valid(text, utcnow):
         replacements = {"tzinfo": tzinfo}
         replacements["hour"] = 12 if tzinfo == timezone.utc else 0
         valid = datetime24(valid, replacements)
-    return station, valid, extra
+        basevalid = valid
+    return station, basevalid, valid, extra
 
 
 def process_di(text):
@@ -299,14 +323,21 @@ def process_modifiers(text, diction, basevalid):
         diction.data_created = parse_dc(text[2:], diction.valid)
     elif text.startswith("DD"):
         diction.valid = parse_dd(text[2:], diction.valid)
+        diction.basevalid = diction.valid
+    elif text.startswith("DY"):
+        diction.valid = parse_dy(text[2:], diction.valid)
+        diction.basevalid = diction.valid
     elif text.startswith("DH"):
-        diction.valid = parse_dh(text[2:], diction.valid)
+        # Careful here, want DH to modify the basevalid and not current valid
+        diction.valid = parse_dh(text[2:], diction.basevalid)
     elif text.startswith("DM"):
         diction.valid = parse_dm(text[2:], diction.valid)
+        diction.basevalid = diction.valid
     elif text.startswith("DQ"):
         diction.qualifier = text[2]
     elif text.startswith("DT"):
         diction.valid = parse_dt(text[2:], diction.valid)
+        diction.basevalid = diction.valid
     elif text.startswith("DU"):
         diction.unit_convention = text[2]
     elif text.startswith("DV"):
@@ -321,8 +352,13 @@ def process_modifiers(text, diction, basevalid):
             "Y": "years",
         }
         if val in reps:
-            replace = {reps[val]: int(text[3:])}
-            diction.dv_interval = timedelta(**replace)
+            # Ensure this is an integer
+            _text = text[3:].strip()
+            if _text.isdigit():
+                replace = {reps[val]: int(_text)}
+                diction.dv_interval = timedelta(**replace)
+            else:
+                LOG.warning("DV with non-numeric value '%s'", _text)
         else:
             raise ValueError(f"Unsupported DV code {text}")
     elif text.startswith("DR"):
@@ -348,7 +384,7 @@ def process_message_e(message, utcnow=None) -> List[SHEFElement]:
     tokens = message.split("/")
     # In the first token, we should find some information about the station
     # and timing.  Otherstuff could be here as well
-    station, valid, extra = parse_station_valid(tokens[0], utcnow)
+    station, basevalid, valid, extra = parse_station_valid(tokens[0], utcnow)
     tokens = tokens[1:]
     if extra:
         extra.extend(tokens)
@@ -359,7 +395,7 @@ def process_message_e(message, utcnow=None) -> List[SHEFElement]:
     # Iterate through the next tokens and hopefully find DI
     interval = timedelta(seconds=0)
     # Create element object to track as we parse through the message
-    diction = SHEFElement(station=station, valid=valid)
+    diction = SHEFElement(station=station, basevalid=basevalid, valid=valid)
     for token in tokens:
         token = token.lstrip()
         if process_modifiers(token, diction, valid):
@@ -425,14 +461,16 @@ def process_message_b(message, utcnow=None) -> List[SHEFElement]:
     lines = message.split("\n")
     headerline = clean_b_headerline(lines[0])
     tokens = headerline.split("/")
-    _center, valid, extra = parse_station_valid(tokens[0], utcnow)
+    _center, basevalid, valid, extra = parse_station_valid(tokens[0], utcnow)
     tokens = tokens[1:]
     if extra:
         extra.extend(tokens)
         tokens = extra
     # Keep track of our dictions.
     dictions = []
-    current_diction = SHEFElement(station="NA", valid=valid)
+    current_diction = SHEFElement(
+        station="NA", basevalid=basevalid, valid=valid
+    )
     for token in tokens:
         token = token.strip()
         if token == "":
@@ -542,7 +580,7 @@ def process_message_a(message, utcnow=None) -> List[SHEFElement]:
     if len(tokens) == 1:
         return []
     # First tokens should have some mandatory stuff
-    station, valid, extra = parse_station_valid(tokens[0], utcnow)
+    station, basevalid, valid, extra = parse_station_valid(tokens[0], utcnow)
     if valid is None:
         # This is an empty message
         return []
@@ -551,7 +589,7 @@ def process_message_a(message, utcnow=None) -> List[SHEFElement]:
         extra.extend(tokens)
         tokens = extra
     elements = []
-    diction = SHEFElement(station=station, valid=valid)
+    diction = SHEFElement(station=station, basevalid=basevalid, valid=valid)
     for text in tokens:
         text = text.strip()
         if text == "":
@@ -589,7 +627,7 @@ def process_messages(func, prod, messages) -> int:
             # Swallow these generally, but let no station slide
             if str(exp).find("3.2") != 0:
                 errors += 1
-            LOG.info("%s for '%s' %s", exp, message, prod.get_product_id())
+            LOG.warning("%s for '%s' %s", exp, message, prod.get_product_id())
         except Exception as exp:
             errors += 1
             cstr = StringIO()
@@ -611,13 +649,15 @@ def parse_A(prod):
         if line.startswith(".AR ") or line.startswith(".A "):
             messages.append(strip_comments(line))
             continue
+        if not messages:
+            continue
         if line.startswith(".A"):  # continuation
             # Accounts for a line with no data, just comments
             meat = strip_comments(line).split(maxsplit=1)
             if len(meat) == 2:
                 messages[-1] += f"/{meat[1]}"
         # Look for comments coming after the first message
-        if messages and line.startswith(":"):
+        if line.startswith(":"):
             narrative += line[1:].strip() + " "
 
     process_messages(process_message_a, prod, messages)
@@ -718,8 +758,7 @@ def compute_num_value(element) -> bool:
     try:
         element.num_value = float(element.str_value)
     except ValueError:
-        print(element.str_value)
-        LOG.info("ValueError: '%s' to float failed", element.str_value)
+        LOG.warning("ValueError: '%s' to float failed", element.str_value)
         return False
     # 5.1.2 Precip is assumed to be in 0.01 inches if an integer is provided
     if (
