@@ -4,12 +4,13 @@
 
 This module contains utility functions used by various parts of the codebase.
 """
+from contextlib import contextmanager
 import os
 import sys
 import time
 import random
 import logging
-from datetime import timezone, datetime
+from datetime import timezone, datetime, date, timedelta
 import re
 import warnings
 import getpass
@@ -23,6 +24,7 @@ from psycopg2.extensions import register_adapter, AsIs
 import numpy as np
 from metpy.units import units, masked_array
 import requests
+from sqlalchemy import create_engine
 
 # NB: some third party stuff is expensive to import, so let us be lazy
 
@@ -52,13 +54,11 @@ class CustomFormatter(logging.Formatter):
 
     def format(self, record):
         """Return a string!"""
-        return "[%s %6.3f %s:%s %s] %s" % (
-            time.strftime("%H:%M:%S", time.localtime(record.created)),
-            record.relativeCreated / 1000.0,
-            record.filename,
-            record.lineno,
-            record.funcName,
-            record.getMessage(),
+        return (
+            f"[{time.strftime('%H:%M:%S', time.localtime(record.created))} "
+            f"{(record.relativeCreated / 1000.0):6.3f} "
+            f"{record.filename}:{record.lineno} {record.funcName}] "
+            f"{record.getMessage()}"
         )
 
 
@@ -189,7 +189,7 @@ def logger(name="pyiem", level=None):
     Args:
       name (str): The name of the logger to get, default pyiem
       level (logging.LEVEL): The log level for this pyiem logget, default is
-        INFO for non interactive sessions, DEBUG otherwise
+        WARNING for non interactive sessions, INFO otherwise
 
     Returns:
       logger instance
@@ -199,8 +199,8 @@ def logger(name="pyiem", level=None):
     log = logging.getLogger(name)
     log.addHandler(ch)
     if level is None and sys.stdout.isatty():
-        level = logging.DEBUG
-    log.setLevel(level if level is not None else logging.INFO)
+        level = logging.INFO
+    log.setLevel(level if level is not None else logging.WARNING)
     return log
 
 
@@ -273,7 +273,7 @@ def ncopen(ncfn, mode="r", timeout=60):
     import netCDF4
 
     if mode != "w" and not os.path.isfile(ncfn):
-        raise IOError("No such file %s" % (ncfn,))
+        raise IOError(f"No such file {ncfn}")
     sts = datetime.utcnow()
     nc = None
     while (datetime.utcnow() - sts).total_seconds() < timeout:
@@ -302,6 +302,42 @@ def utc(year=None, month=1, day=1, hour=0, minute=0, second=0, microsecond=0):
     ).replace(tzinfo=timezone.utc)
 
 
+def get_dbconnstr(name, **kwargs) -> str:
+    """Create a database connection string/URI.
+
+    Args:
+      name (str): the database name to connect to.
+      **kwargs: any additional arguments to pass to psycopg2.connect
+        user (str): the database user to connect as
+        host (str): the database host to connect to
+        port (int): the database port to connect to
+    Returns:
+      str
+    """
+    user = kwargs.get("user")
+    if user is None:
+        user = getpass.getuser()
+        # We hard code the apache user back to nobody, www-data is travis-ci
+        if user in ["apache", "www-data"]:
+            user = "nobody"
+        elif user == "akrherz":  # HACK for daryl's development, sigh
+            user = "mesonet"
+        elif user == "meteor_ldm":  # Another HACK
+            user = "ldm"
+    host = kwargs.get("host")
+    if host is None:
+        host = f"iemdb-{name}.local"
+    port = kwargs.get("port")
+    if port is None:
+        port = 5432
+
+    return (
+        f"postgresql://{user}@{host}:{port}/{name}?"
+        f"connect_timeout={kwargs.get('connect_timeout', 15)}&"
+        f"gssencmode={kwargs.get('gssencmode', 'disable')}&"
+    )
+
+
 def get_dbconn(database="mesosite", user=None, host=None, port=5432, **kwargs):
     """Helper function with business logic to get a database connection
 
@@ -321,41 +357,14 @@ def get_dbconn(database="mesosite", user=None, host=None, port=5432, **kwargs):
     Returns:
       psycopg2 database connection
     """
-
-    if user is None:
-        user = getpass.getuser()
-        # We hard code the apache user back to nobody, www-data is travis-ci
-        if user in ["apache", "www-data"]:
-            user = "nobody"
-        elif user == "akrherz":  # HACK for daryl's development, sigh
-            user = "mesonet"
-        elif user == "meteor_ldm":  # Another HACK
-            user = "ldm"
-    if host is None:
-        host = "iemdb-%s.local" % (database,)
-    conn_kwargs = {
-        "database": database,
-        "host": host,
-        "user": user,
-        "password": kwargs.get("password"),
-        "port": port,
-        "connect_timeout": kwargs.get("connect_timeout", 15),
-        "gssencmode": kwargs.get("gssencmode", "disable"),
-    }
-    conn_kwargs.update(kwargs)
+    dsn = get_dbconnstr(database, user=user, host=host, port=port, **kwargs)
     attempt = 0
     while attempt < 3:
         attempt += 1
         try:
-            return psycopg2.connect(**conn_kwargs)
+            return psycopg2.connect(dsn)
         except psycopg2.ProgrammingError as exp:
-            # Likely gssencmode is not permitted
-            if "gssencmode" in conn_kwargs:
-                conn_kwargs.pop("gssencmode")
-            else:
-                warnings.warn(
-                    f"database connection failure: {exp}", stacklevel=2
-                )
+            warnings.warn(f"database connection failure: {exp}", stacklevel=2)
             if attempt == 3:
                 raise exp
         except psycopg2.OperationalError as exp:
@@ -367,6 +376,26 @@ def get_dbconn(database="mesosite", user=None, host=None, port=5432, **kwargs):
             )
 
 
+@contextmanager
+def get_sqlalchemy_conn(text, **kwargs):
+    """An auto-disposing sqlalchemy context-manager helper.
+
+    This is used for when we really do not want to manage having pools of
+    database connections open.  So this isn't something that is fast!
+
+    Args:
+        text (str): the database to connect to, passed to get_dbconnstr
+        **kwargs: any additional arguments to pass to get_dbconnstr
+    """
+    engine = create_engine(get_dbconnstr(text, **kwargs))
+    try:
+        # Unsure if this is trouble or not.
+        with engine.connect() as conn:
+            yield conn
+    finally:
+        engine.dispose()
+
+
 def noaaport_text(text):
     """Make whatever text look like it is NOAAPort Pristine
 
@@ -398,7 +427,25 @@ def noaaport_text(text):
     return "\r\r\n".join(lines)
 
 
-def get_autoplot_context(fdict, cfg, enforce_optional=False):
+def handle_date_err(exp, value, fmt):
+    """Attempt to fix up a date string, when possible."""
+    if str(exp).find("day is out of range") == -1:
+        raise exp
+    tokens = value.split(" ")
+    datepart = tokens[0]
+    (yyyy, mm, _dd) = datepart.split("-")
+    # construct a new month date and then substract one day
+    lastday = (date(int(yyyy), int(mm), 15) + timedelta(days=20)).replace(
+        day=1
+    ) - timedelta(days=1)
+    # Reconstruct the date string
+    res = lastday.strftime("%Y-%m-%d")
+    if len(tokens) > 1:
+        res += " " + tokens[1]
+    return datetime.strptime(res, fmt)
+
+
+def get_autoplot_context(fdict, cfg, enforce_optional=False, **kwargs):
     """Get the variables out of a dict of strings
 
     This helper for IEM autoplot gets values out of a dictionary of strings,
@@ -411,11 +458,18 @@ def get_autoplot_context(fdict, cfg, enforce_optional=False):
       fdict (dictionary): what was likely provided by `cgi.FieldStorage()`
       cfg (dictionary): autoplot value of get_description
       enforce_optional (bool,optional): Should the `optional` flag be enforced
+      rectify_dates (bool,optional): Attempt to fix common date errors like
+        June 31.  Default `false`.
 
     Returns:
       dictionary of variable names and values, with proper types!
     """
     ctx = {}
+    # This quasi sucks
+    for arg in ["dpi", "_r"]:
+        val = fdict.get(arg)
+        if val is not None:
+            ctx[arg] = val if arg != "dpi" else int(val)
     for opt in cfg.get("arguments", []):
         name = opt.get("name")
         default = opt.get("default")
@@ -436,16 +490,13 @@ def get_autoplot_context(fdict, cfg, enforce_optional=False):
             continue
         if typ in ["station", "zstation", "sid", "networkselect"]:
             # A bit of hackery here if we have a name ending in a number
-            netname = "network%s" % (
-                name[-1] if name[-1] in ["1", "2", "3", "4", "5"] else "",
-            )
+            _n = name[-1] if name[-1] in ["1", "2", "3", "4", "5"] else ""
+            netname = f"network{_n}"
             # The network variable tags along and within a non-PHP context,
             # this variable is unset, so we do some more hackery here
             ctx[netname] = fdict.get(netname, opt.get("network"))
             # Convience we load up the network metadata
-            ntname = "_nt%s" % (
-                name[-1] if name[-1] in ["1", "2", "3", "4", "5"] else "",
-            )
+            ntname = f"_nt{_n}"
             from pyiem.network import Table as NetworkTable
             from pyiem.exceptions import NoDataFound
 
@@ -493,7 +544,17 @@ def get_autoplot_context(fdict, cfg, enforce_optional=False):
             if value is not None:
                 if value.find(" ") == -1:
                     value += " 0000"
-                value = datetime.strptime(value, "%Y-%m-%d %H%M")
+                _dtfmt = "%Y-%m-%d %H%M"
+                try:
+                    value = datetime.strptime(value, "%Y-%m-%d %H%M")
+                except ValueError as exp:
+                    if kwargs.get("rectify_dates", False):
+                        value = handle_date_err(exp, value, _dtfmt)
+                    else:
+                        # If we are not rectifying dates, we just raise the
+                        # exception
+                        raise
+
         elif typ == "date":
             # tricky here, php has YYYY/mm/dd and CGI has YYYY-mm-dd
             if default is not None:
@@ -503,7 +564,15 @@ def get_autoplot_context(fdict, cfg, enforce_optional=False):
             if maxval is not None:
                 maxval = datetime.strptime(maxval, "%Y/%m/%d").date()
             if value is not None:
-                value = datetime.strptime(value, "%Y-%m-%d").date()
+                try:
+                    value = datetime.strptime(value, "%Y-%m-%d").date()
+                except ValueError as exp:
+                    if kwargs.get("rectify_dates", False):
+                        value = handle_date_err(exp, value, "%Y-%m-%d").date()
+                    else:
+                        # If we are not rectifying dates, we just raise the
+                        # exception
+                        raise
         elif typ == "vtec_ps":
             # VTEC phenomena and significance
             defaults = {}
@@ -527,6 +596,10 @@ def get_autoplot_context(fdict, cfg, enforce_optional=False):
         if maxval is not None and value is not None and value > maxval:
             value = default
         ctx[name] = value if value is not None else default
+    # Ensure defaults are set, if they exist
+    for key in cfg.get("defaults", {}):
+        if key not in ctx:
+            ctx[key] = cfg["defaults"][key]
     return ctx
 
 
@@ -542,10 +615,10 @@ def exponential_backoff(func, *args, **kwargs):
         try:
             return func(*args, **kwargs)
         except socket_error as serr:
-            msgs.append("%s/5 %s traceback: %s" % (i + 1, func.__name__, serr))
+            msgs.append(f"{i+1}/5 {func.__name__} traceback: {serr}")
             time.sleep((ebfactor ** i) + (random.randint(0, 1000) / 1000))
         except Exception as exp:
-            msgs.append("%s/5 %s traceback: %s" % (i + 1, func.__name__, exp))
+            msgs.append(f"{i+1}/5 {func.__name__} traceback: {exp}")
             time.sleep((ebfactor ** i) + (random.randint(0, 1000) / 1000))
     logging.error("%s failure", func.__name__)
     logging.error("\n".join(msgs))
