@@ -21,6 +21,46 @@ from pyiem.reference import TRACE_VALUE
 from pyiem.util import utc, get_test_file
 
 
+def test_220224_redundant_dh():
+    """Test that a product with redundant DH values does not fool us."""
+    prod = parser(get_test_file("SHEF/RR3GJT.txt"), utcnow=utc(2022, 2, 25))
+    assert prod.data[4].valid == utc(2022, 2, 24, 7)
+
+
+def test_dy():
+    """Test support for the DY time variable."""
+    msg = (
+        ".BR GAMMA 220202 /SAIRF/SWIRF\n"
+        "IA111  DY220202 / 100 / 2.2 : 1.8, 27 AM 210927 , 27  \n"
+        "IA112  DY2202021112 / 100 / 2.2 : 1.8, 27 AM 210927 , 27  \n"
+        ".END"
+    )
+    res = process_message_b(msg)
+    assert res[0].valid == utc(2022, 2, 2, 12)
+    assert res[2].valid == utc(2022, 2, 2, 11, 12)
+
+
+def test_220125_dv():
+    """Test various combinations of DV that DTX came up with."""
+    prod = parser(get_test_file("SHEF/DV.txt"), utcnow=utc(2022, 1, 25, 18))
+    assert prod.data[0].dv_interval == timedelta(hours=24)
+    assert prod.data[1].dv_interval is None
+    assert prod.data[2].dv_interval is None
+
+
+def test_211230_rrmsgx():
+    """Test that no exception happens with a non SHEF containing RRM."""
+    prod = parser(get_test_file("SHEF/RRMSGX.txt"), utcnow=utc(2021, 12, 30))
+    assert not prod.data
+
+
+def test_211025_rr3mkx():
+    """Test that we do not take some of the bad data here."""
+    utcnow = utc(2021, 10, 25)
+    prod = parser(get_test_file("SHEF/RR3MKX.txt"), utcnow=utcnow)
+    assert not prod.data
+
+
 def test_a_format():
     """Test the parsing of A format SHEF."""
     utcnow = utc(2021, 9, 17, 12)
@@ -333,7 +373,7 @@ def test_qualifier():
 
 def test_parse_station_valid():
     """Test handling of odd things."""
-    station, _valid, res = parse_station_valid(".A DMX 0919", utc())
+    station, _base, _valid, res = parse_station_valid(".A DMX 0919", utc())
     assert station == "DMX"
     assert not res
 
