@@ -7,16 +7,36 @@ import copy
 import pytest
 import matplotlib.colors as mpcolors
 import numpy as np
+from shapely.geometry import Polygon
+
+# Local
 from pyiem import plot
 from pyiem.plot import (
     MapPlot,
     centered_bins,
     pretty_bins,
     load_bounds,
+    mask_outside_geom,
 )
+from pyiem.reference import TWITTER_RESOLUTION_INCH
 from pyiem.util import utc
 
-PAIN = 1.1  # how much do we care, sigh.
+PAIN = 1.3  # how much do we care, sigh.
+
+
+def test_exercise_usdm():
+    """Test the various checks in the usdm method."""
+    mp = MapPlot()
+    mp.draw_usdm()
+    mp.draw_usdm(utc())
+    assert mp.draw_usdm("qqq") is None
+    assert mp.draw_usdm(utc(1980, 1, 1)) is None
+
+
+def test_close():
+    """Test that the close method works."""
+    mp = MapPlot()
+    mp.close()
 
 
 def test_invalid_file():
@@ -25,6 +45,50 @@ def test_invalid_file():
 
 
 @pytest.mark.mpl_image_compare(tolerance=PAIN)
+def test_axes_position():
+    """Test control of the main axes position."""
+    mp = MapPlot(
+        nocaption=True,
+        title="Small Axes",
+        axes_position=[0.3, 0.3, 0.3, 0.3],
+    )
+    return mp.fig
+
+
+@pytest.mark.mpl_image_compare(tolerance=PAIN)
+def test_fill_ugcs_year_label():
+    """Test that we can control the format of the label shown."""
+    mp = MapPlot(
+        nocaption=True,
+        title="All Years",
+        apctx={"_r": "t"},  # piggy back a change to figure size
+    )
+    assert mp.fig.get_size_inches()[0] == TWITTER_RESOLUTION_INCH[0]
+    data = {"IAC001": 2021, "IAC003": 2021.5}
+    mp.fill_ugcs(data, ilabel=True, lblformat="%.0f")
+    return mp.fig
+
+
+@pytest.mark.mpl_image_compare(tolerance=PAIN)
+def test_china():
+    """Test that we can draw china and not overlay any cwas."""
+    mp = MapPlot(
+        twitter=True,
+        nocaption=True,
+        sector="custom",
+        south=13,
+        north=55,
+        east=100,
+        west=70,
+        title="China",
+        apctx={"_r": "bogus"},  # this should be a noop
+    )
+    assert mp.fig.get_size_inches()[0] == TWITTER_RESOLUTION_INCH[0]
+    mp.fill_climdiv({"bah": 7})
+    return mp.fig
+
+
+@pytest.mark.mpl_image_compare(tolerance=2)  # unknown python3.7 diff
 def test_nws_sector_twitter_res():
     """Test that Hawaii does not overlap Florida for Twitter Res."""
     mp = MapPlot(
@@ -121,7 +185,7 @@ def test_overlay_roadcond():
     """Test being able to plot Iowa Road Conditions."""
     mp = MapPlot(
         nocaption=True,
-        sector="iowa",
+        apctx={"csector": "IA"},
         title="A long and long title that has no purpose but to test things",
     )
     mp.overlay_roadcond(utc(2021, 2, 4, 17))
@@ -145,8 +209,8 @@ def test_overlay_nexrad_hawaii():
     """Test that we can plot nexrad over Hawaii."""
     mp = MapPlot(
         nocaption=True,
-        sector="state",
-        state="HI",
+        sector="iowa",  # this gets overridden
+        apctx={"csector": "HI"},
         title="A long and long title that has no purpose but to test things",
     )
     caxpos = [0.05, 0.05, 0.35, 0.015]
@@ -185,7 +249,7 @@ def test_conus_contour():
     """Test that a conus sector plot can generate a contour correctly."""
     mp = MapPlot(nocaption=True, sector="conus", twitter=True)
     mp.contourf(
-        np.arange(-120, -47, 3),
+        list(np.arange(-120, -47, 3)),
         np.arange(25, 50),
         np.arange(25),
         np.arange(25),
@@ -195,6 +259,22 @@ def test_conus_contour():
     return mp.fig
 
 
+@pytest.mark.mpl_image_compare(tolerance=PAIN)
+def test_iowa_contour_with_polygon_mask():
+    """Test that we can mask with a single Polygon."""
+    mp = MapPlot(nocaption=True, sector="iowa", twitter=True)
+    mp.contourf(
+        np.arange(-120, -47, 3),
+        np.arange(25, 50),
+        np.arange(25),
+        np.arange(25),
+        clip_on=False,
+    )
+    poly = Polygon([(-95, 40), (-95, 45), (-90, 45), (-90, 40)])
+    mask_outside_geom(mp.panels[0], poly)
+    return mp.fig
+
+
 @pytest.mark.mpl_image_compare(tolerance=PAIN)
 def test_issue365_cape_cod():
     """Test that we don't mask out Cape Cod."""
@@ -239,11 +319,13 @@ def test_issue98_labelbar():
     clevs = np.arange(0, 1.0, 0.1)
     clevs[-1] = 3.987654
     norm = mpcolors.BoundaryNorm(clevs, cmap.N)
+    colors = cmap(norm([0.5, 0.25, 1.0, 5.0]))
+    colors = [mpcolors.to_hex(c) for c in colors]
     mp.plot_values(
         [-94, -92, -91, -92],
         [42, 41, 43, 42.4],
         ["0.5", "0.25", "1.0", "5.0"],
-        color=cmap(norm([0.5, 0.25, 1.0, 5.0])),
+        color=colors,
         showmarker=True,
     )
     mp.draw_colorbar(clevs, cmap, norm, spacing="proportional")
@@ -284,7 +366,7 @@ def test_fill_ugcs_color():
     data = {"IAC001": 10, "IAC003": 20, "IAC135": 30}
     fc = {"IAC001": "#FF0000", "IAC003": "black"}
     ec = {}
-    mp.fill_ugcs(data, fc=fc, ec=ec, nocbar=True)
+    mp.fill_ugcs(data, fc=fc, ec=ec, draw_colorbar=False)
     return mp.fig
 
 
@@ -303,6 +385,14 @@ def test_usdm():
     return mp.fig
 
 
+@pytest.mark.mpl_image_compare(tolerance=PAIN)
+def test_usdm_filled():
+    """Can we plot the USDM filled."""
+    mp = MapPlot(sector="southwest", nocaption=True)
+    mp.draw_usdm(valid=datetime.date(2018, 5, 7), hatched=False, filled=True)
+    return mp.fig
+
+
 @pytest.mark.mpl_image_compare(tolerance=PAIN)
 def test_hexbin():
     """See if we can do hexbin OKish"""
@@ -409,12 +499,14 @@ def test_drawrandomtext():
         debug=True,
         nocaption=True,
     )
-    mp.plot_values(
-        [-94, -92, -91, -92],
-        [42, 41, 43, 42.4],
-        ["One", "Two\nTwo", "Three\nThree\nThree", "Four\nFour\nFour\nFour"],
-        showmarker=True,
-    )
+    lons = [-94, -92, -91, -92]
+    lats = [42, 41, 43, 42.4]
+    vals = ["One", "Two\nTwo", "Three\nThree\nThree", "Four\nFour\nFour\nFour"]
+    # Add some cruft to exercise culling
+    lons.extend([lons[-1]] * 500)
+    lats.extend([lats[-1]] * 500)
+    vals.extend([vals[-1]] * 500)
+    mp.plot_values(lons, lats, vals, showmarker=True)
     return mp.fig
 
 
@@ -432,6 +524,26 @@ def test_drawiowawfo():
     return mp.fig
 
 
+@pytest.mark.mpl_image_compare(tolerance=PAIN)
+def test_contourf_grid():
+    """Test that contourf can handle a 2d grid"""
+    mp = MapPlot(title="Iowa Contour plot", nocaption=True)
+    x = np.arange(-94, -85)
+    y = np.arange(36, 45)
+    xx, yy = np.meshgrid(x, y)
+    vals = xx
+    mp.contourf(
+        xx,
+        yy,
+        vals,
+        np.arange(-94, -85),
+        clevlabels=["a", "b", "c", "d", "e", "f", "g", "h", "i"],
+        ilabel=True,
+        iline=True,
+    )
+    return mp.fig
+
+
 @pytest.mark.mpl_image_compare(tolerance=PAIN)
 def test_fillstates():
     """Can we fill states"""
@@ -446,15 +558,17 @@ def test_fillstates():
     return mp.fig
 
 
-@pytest.mark.mpl_image_compare(tolerance=0.25)
+@pytest.mark.mpl_image_compare(tolerance=PAIN)
 def test_drawcounties():
     """draw counties on the map"""
-    mp = MapPlot(sector="midwest", title="Counties", nocaption=True)
+    mp = MapPlot(
+        apctx={"csector": "midwest"}, title="Counties", nocaption=True
+    )
     mp.drawcounties()
     return mp.fig
 
 
-@pytest.mark.mpl_image_compare(tolerance=0.25)
+@pytest.mark.mpl_image_compare(tolerance=PAIN)
 def test_drawcounties_cornbelt():
     """draw counties on the map"""
     mp = MapPlot(sector="cornbelt", title="Counties", nocaption=True)
@@ -534,7 +648,12 @@ def test_colorbar3():
     clevs = [0, 100, 250, 500, 1000, 2000, 20000]
     norm = mpcolors.BoundaryNorm(clevs, cmap.N)
     mp.draw_colorbar(
-        clevs, cmap, norm, title="Erosion $kg/m^2$", spacing="uniform"
+        clevs,
+        cmap,
+        norm,
+        title="Erosion $kg/m^2$",
+        spacing="uniform",
+        extend="max",
     )
     return mp.fig
 
@@ -705,10 +824,10 @@ def test_colorramps():
 def test_overlap():
     """Do some checking of our overlaps logic"""
     mp = MapPlot(sector="midwest", continentalcolor="white", nocaption=True)
-    lons = np.linspace(-99, -90, 100)
-    lats = np.linspace(38, 44, 100)
-    vals = lats
-    labels = ["%.2f" % (s,) for s in lats]
+    lons = list(np.linspace(-99, -90, 100))
+    lats = list(np.linspace(38, 44, 100))
+    vals = list(lats)
+    labels = [f"{s:.2f}" for s in lats]
     mp.plot_values(lons, lats, vals, fmt="%.2f", labels=labels)
     return mp.fig
 
@@ -718,7 +837,16 @@ def test_barbs():
     """Testing the plotting of wind barbs"""
     mp = MapPlot(continentalcolor="white", nocaption=True)
     data = [
-        dict(lat=41.5, lon=-96, tmpf=50, dwpf=30, sknt=10, drct=100),
+        dict(
+            lat=41.5,
+            lon=-96,
+            tmpf=50,
+            dwpf=30,
+            sknt=10,
+            drct=100,
+            coverage=50,
+        ),
+        dict(lat=42.0, lon=-95.5, tmpf=50, dwpf=30, sknt=20, drct=200),
         dict(lat=42.0, lon=-95.5, tmpf=50, dwpf=30, sknt=20, drct=200),
     ]
     mp.plot_station(data, fontsize=12)
@@ -785,7 +913,7 @@ def test_textplot2():
         np.arange(-99, -94),
         np.arange(40, 45),
         np.arange(5),
-        labels=range(5, 11),
+        labels=range(5, 10),
     )
     return mp.fig
 
