@@ -64,42 +64,6 @@ def test_forecast_grids():
     iemre.set_grids(valid, ds, cursor=cursor, table="iemre_daily_forecast")
 
 
-def test_get_grids():
-    """Can we get grids?"""
-    pgconn = get_dbconn("iemre")
-    cursor = pgconn.cursor()
-    valid = utc(2019, 12, 1, 1)
-    cursor.execute(
-        """
-        DELETE from iemre_hourly_201912 WHERE valid = %s
-    """,
-        (valid,),
-    )
-    cursor.execute(
-        """
-        DELETE from iemre_hourly_201912 WHERE valid = %s
-    """,
-        (valid + datetime.timedelta(days=1),),
-    )
-    cursor.execute(
-        """
-        INSERT into iemre_hourly_201912
-        (gid, valid, tmpk, dwpk, uwnd, vwnd, p01m)
-        select gid, %s, random(), null, random(),
-        random(), random() from iemre_grid LIMIT 100
-    """,
-        (valid,),
-    )
-    ds = iemre.get_grids(valid, varnames="tmpk", cursor=cursor)
-    assert "tmpk" in ds
-    assert "bogus" not in ds
-    ds = iemre.get_grids(valid, cursor=cursor)
-    assert np.isnan(ds["dwpk"].values.max())
-
-    iemre.set_grids(valid, ds, cursor=cursor)
-    iemre.set_grids(valid + datetime.timedelta(days=1), ds, cursor=cursor)
-
-
 def test_simple():
     """Get nulls for right and top values"""
     i, j = iemre.find_ij(iemre.EAST, iemre.NORTH)
