@@ -1,11 +1,10 @@
 """Generate the _ccw files used in pyIEM."""
 
+from shapely.wkb import loads
+from shapely.geometry import MultiPolygon
+import numpy as np
 from pyiem.plot import MapPlot
 from pyiem.util import get_dbconn
-from shapely.wkb import loads
-from shapely.geometry import Polygon, MultiPolygon
-from descartes.patch import PolygonPatch
-import numpy as np
 
 
 def main():
@@ -33,23 +32,18 @@ def main():
     vals = np.linspace(0, 50, 50)
     m.contourf(lons, lats, vals, vals)
 
-    # """
     for row in cursor:
         multipoly = MultiPolygon([loads(row[0], hex=True)])
         for geo in multipoly.geoms:
             if geo.area < 1:
                 continue
             (lons, lats) = geo.exterior.xy
-            print("Masking with geo... %s %s" % (geo.area, len(lons)))
+            print(f"Masking with geo... {geo.area} {len(lons)}")
 
             ar = list(zip(lons, lats))
             ar.reverse()
             np.save("iailin_ccw.npy", ar)
             # mask_outside_polygon(ar, ax=m.ax)
-            poly = PolygonPatch(Polygon(ar), fc="r", zorder=10000)
-            m.ax.add_patch(poly)
-    # """
-    m.postprocess(filename="test.png")
 
 
 if __name__ == "__main__":
