@@ -1,6 +1,7 @@
 """Serialization of geometries for use in pyIEM.plot mapping."""
 import datetime
 import warnings
+import sys
 
 import geopandas as gpd
 from geopandas import read_postgis
@@ -72,7 +73,8 @@ def dump_cwa(fn):
 
     df = read_postgis(
         """
-        SELECT wfo, ST_Simplify(the_geom, 0.01) as geom,
+        SELECT wfo,
+        ST_Multi(ST_Buffer(ST_Simplify(the_geom, 0.01), 0)) as geom,
         ST_x(ST_Centroid(the_geom)) as lon,
         ST_Y(ST_Centroid(the_geom)) as lat, region
         from cwa""",
@@ -80,11 +82,12 @@ def dump_cwa(fn):
         index_col="wfo",
         geom_col="geom",
     )
+
     df.to_parquet(fn)
 
 
 def dump_iowawfo(fn):
-    """ A region with the Iowa WFOs"""
+    """A region with the Iowa WFOs"""
     pgconn = get_dbconn("postgis", user="nobody")
 
     df = read_postgis(
@@ -125,7 +128,10 @@ def check_file(fn):
     sts = datetime.datetime.now()
     df = gpd.read_parquet(fn)
     ets = datetime.datetime.now()
-
+    for geom in df["geom"]:
+        if not geom.is_valid:
+            print("Invalid Geom Found?")
+            sys.exit()
     print(
         "runtime: %.5fs, entries: %s, fn: %s"
         % ((ets - sts).total_seconds(), len(df.index), fn)
